@@ -2,17 +2,16 @@
 
 #include <tins/tins.h>
 
-#include <boost/iostreams/filtering_stream.hpp>
 #include <filesystem>
 #include <fstream>
+#include <memory>
 #include <optional>
 #include <string>
 #include <thread>
 
-#include "statistics.hpp"
+#include "./statistics.hpp"
 
 namespace fs = std::filesystem;
-namespace io = boost::iostreams;
 
 namespace caracal {
 
@@ -36,8 +35,7 @@ class Sniffer {
 
  private:
   Tins::Sniffer sniffer_;
-  std::ofstream output_csv_ofs_;
-  io::filtering_stream<io::output> output_csv_;
+  std::unique_ptr<std::ostream> output_csv_;
   std::optional<Tins::PacketWriter> output_pcap_;
   std::optional<std::string> meta_round_;
   std::thread thread_;
