@@ -3,8 +3,7 @@
 #include <spdlog/spdlog.h>
 #include <tins/tins.h>
 
-#include <boost/iostreams/device/file.hpp>
-#include <boost/iostreams/filter/zstd.hpp>
+#include <bxzstr/bxzstr.hpp>
 #include <caracal/parser.hpp>
 #include <caracal/sniffer.hpp>
 #include <caracal/statistics.hpp>
@@ -15,7 +14,6 @@
 #include <optional>
 #include <thread>
 
-namespace io = boost::iostreams;
 namespace fs = std::filesystem;
 
 namespace caracal {
@@ -32,41 +30,47 @@ Sniffer::Sniffer(const std::string &interface_name,
       integrity_check_{integrity_check} {
   Tins::NetworkInterface interface { interface_name };
 
-  std::vector<std::string> address_filters;
-  for (auto address : Utilities::all_ipv4_for(interface)) {
-    address_filters.push_back(fmt::format("dst {}", address.to_string()));
-  }
-  for (auto address : Utilities::all_ipv6_for(interface)) {
-    address_filters.push_back(fmt::format("dst {}", address.to_string()));
-  }
-
-  auto filter_template =
-      "({}) and (icmp or icmp6) and ("
-      "icmp[icmptype] = icmp-echoreply or"
-      " icmp[icmptype] = icmp-timxceed or"
-      " icmp[icmptype] = icmp-unreach or"
-      " icmp6[icmp6type] = icmp6-echoreply or"
-      " icmp6[icmp6type] = icmp6-timeexceeded or"
-      " icmp6[icmp6type] = icmp6-destinationunreach"
-      ")";
-  auto filter = fmt::format(fmt::runtime(filter_template),
-                            fmt::join(address_filters, " or "));
+  auto filter =
+      "(ip and icmp and ("
+      "icmp[icmptype] = icmp-echoreply or "
+      "icmp[icmptype] = icmp-timxceed or "
+      "icmp[icmptype] = icmp-unreach))"
+      " or "
+      "(ip6 and icmp6 and ("
+      "icmp6[icmp6type] = icmp6-echoreply or "
+      "icmp6[icmp6type] = icmp6-timeexceeded or "
+      "icmp6[icmp6type] = icmp6-destinationunreach))";
   spdlog::info("sniffer_filter={}", filter);
 
   Tins::SnifferConfiguration config;
+  // A buffer of 64M is enough to store ~1M ICMPv6 Time Exceeded replies.
+  // We probably don't need as much but this lets us handle burst of incoming
+  // packets.
   config.set_buffer_size(64 * 1024 * 1024);
+  // Filter as much as possible at the kernel level.
+  // We're only interested in incoming ICMP packets.
+  config.set_direction(PCAP_D_IN);
   config.set_filter(filter);
-  config.set_immediate_mode(true);
+  // `timeout` has two uses here:
+  // 1. Batch deliveries from pcap to reduce syscall overhead
+  //    See "packet buffer timeout" in PCAP(3PCAP) man page.
+  //    See also section 26.2 "BSD Packet Filter" in "Unix Network Programming
+  //    vol. 1".
+  // 2. Allow us to break the capture loop through the `stopped` variable.
+  // This has no impact of RTT computation as packets are timestamped as soon as
+  // they are captured by pcap.
+  config.set_timeout(100);
   sniffer_ = Tins::Sniffer(interface_name, config);
 
   if (output_file_csv) {
-    output_csv_ofs_.open(*output_file_csv);
     if (output_file_csv->extension() == ".zst") {
-      output_csv_.push(io::zstd_compressor(1));
+      output_csv_ = std::make_unique<bxz::ofstream>(*output_file_csv,
+                                                    bxz::Compression::zstd, 1);
+    } else {
+      output_csv_ = std::make_unique<std::ofstream>(*output_file_csv);
     }
-    output_csv_.push(output_csv_ofs_);
   } else {
-    output_csv_.push(std::cout);
+    output_csv_ = std::make_unique<std::ostream>(std::cout.rdbuf());
   }
 
   if (output_file_pcap) {
@@ -82,7 +86,7 @@ Sniffer::~Sniffer() {
 }
 
 void Sniffer::start() noexcept {
-  output_csv_ << Reply::csv_header() << "\n";
+  *output_csv_ << Reply::csv_header() << "\n";
   auto handler = [this](Tins::Packet &packet) {
     auto reply = Parser::parse(packet);
 
@@ -92,7 +96,7 @@ void Sniffer::start() noexcept {
       if (reply->is_time_exceeded()) {
         statistics_.icmp_messages_path.insert(reply->reply_src_addr);
       }
-      output_csv_ << reply->to_csv(meta_round_.value_or("1")) << "\n";
+      *output_csv_ << reply->to_csv(meta_round_.value_or("1")) << "\n";
     } else {
       auto data = packet.pdu()->serialize();
       spdlog::trace("invalid_packet_hex={:02x}", fmt::join(data, ""));
