@@ -2,7 +2,7 @@
 
 #include <caracal/parser.hpp>
 #include <caracal/utilities.hpp>
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 #include <filesystem>
 #include <string>
 #include <vector>
