@@ -1,5 +1,5 @@
 #include <caracal/statistics.hpp>
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 using caracal::Statistics::CircularArray;
 
