@@ -1,5 +1,5 @@
 #include <caracal/timestamp.hpp>
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 #include <chrono>
 #include <thread>
 
